==> replacer-1.1.1%2B1.21.%282-4%29-Fabric-sources.jar: eva/replacer/util/RelPos.java <==
package eva.replacer.util;

import java.util.Arrays;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_243;

public class RelPos {
    private final int[] pos = new int[3];
    private static class_2338 basePos;
    private static class_243 baseVec;

    public static void setBase(class_2338 p) {
        basePos = p;
    }

    public static void setBase(class_243 v, class_2338 p) {
        basePos = p;
        baseVec = new class_243(
                v.method_10216() - p.method_10263(),
                v.method_10214() - p.method_10264(),
                v.method_10215() - p.method_10260()
        );
    }

    public RelPos(class_2338 pos) {
        this.pos[0] = pos.method_10263() - basePos.method_10263();
        this.pos[1] = pos.method_10264() - basePos.method_10264();
        this.pos[2] = pos.method_10260() - basePos.method_10260();
    }

    public RelPos(int... pos) {
        if (pos.length != 3) throw new IllegalArgumentException();
        this.pos[0] = pos[0];
        this.pos[1] = pos[1];
        this.pos[2] = pos[2];
    }

    public class_243 vec() {
        class_243 v = pos().method_46558();
        return new class_243(
                v.method_10216() + baseVec.method_10216(),
                v.method_10214() + baseVec.method_10214(),
                v.method_10215() + baseVec.method_10215()
        );
    }

    public class_2338 pos() {
        return basePos
                .method_30513(class_2350.class_2351.field_11048, this.pos[0])
                .method_30513(class_2350.class_2351.field_11052, this.pos[1])
                .method_30513(class_2350.class_2351.field_11051, this.pos[2]);
    }

    public int[] vals() {
        return pos;
    }

    public boolean equals(RelPos tester) {
        return Arrays.equals(tester.vals(), this.vals());
    }

    public double dist() {
        return Math.sqrt(pos[0] * pos[0] + pos[1] * pos[1] + pos[2] * pos[2]);
    }

//    public double dist(RelPos comp) {
//        int[] temp = new int[] {pos[0] -  comp.pos[0], pos[1] - comp.pos[1], pos[2] - comp.pos[2]};
//        return Math.sqrt(temp[0] * temp[0] + temp[1] * temp[1] + temp[2] * temp[2]);
//    }
//
//    public Direction dirTo(RelPos comp) {
//        int[] temp = new int[] {pos[0] -  comp.pos[0], pos[1] - comp.pos[1], pos[2] - comp.pos[2]};
//        return Direction.getApproximateNearest(temp[0], temp[1], temp[2]);
//    }

    public static final RelPos origin = new RelPos(0, 0, 0);
}

==> replacer-2.2.0%2B1.21.%286-8%29-Fabric-sources.jar: eva/replacer/util/RelPos.java <==
package eva.replacer.util;

import java.util.Arrays;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_243;

public class RelPos {
    private final int[] pos = new int[3];
    private static class_2338 basePos;
    private static class_243 baseVec;

    public static void setBase(class_2338 p) {
        basePos = p;
    }

    public static void setBase(class_243 v, class_2338 p) {
        basePos = p;
        baseVec = new class_243(
                v.method_10216() - p.method_10263(),
                v.method_10214() - p.method_10264(),
                v.method_10215() - p.method_10260()
        );
    }

    public RelPos(class_2338 pos) {
        this.pos[0] = pos.method_10263() - basePos.method_10263();
        this.pos[1] = pos.method_10264() - basePos.method_10264();
        this.pos[2] = pos.method_10260() - basePos.method_10260();
    }

    public RelPos(int... pos) {
        if (pos.length != 3) throw new IllegalArgumentException();
        this.pos[0] = pos[0];
        this.pos[1] = pos[1];
        this.pos[2] = pos[2];
    }

    public class_243 vec() {
        class_243 v = pos().method_46558();
        return new class_243(
                v.method_10216() + baseVec.method_10216(),
                v.method_10214() + baseVec.method_10214(),
                v.method_10215() + baseVec.method_10215()
        );
    }

    public class_2338 pos() {
        return basePos
                .method_30513(class_2350.class_2351.field_11048, this.pos[0])
                .method_30513(class_2350.class_2351.field_11052, this.pos[1])
                .method_30513(class_2350.class_2351.field_11051, this.pos[2]);
    }

    public int[] vals() {
        return pos;
    }

    public boolean equals(RelPos tester) {
        return Arrays.equals(tester.vals(), this.vals());
    }

    double dist() {
        assert pos.length == 3;
        return Math.sqrt(pos[0] * pos[0] + pos[1] * pos[1] + pos[2] * pos[2]);
    }

    double dist(class_243 v) {
        assert pos.length == 3;
        class_243 b = vec().method_1020(v);
        return Math.sqrt(b.method_10216() * b.method_10216() + b.method_10214() * b.method_10214() + b.method_10215() * b.method_10215());
    }

    public RelPos shift(class_2350 direction) {
        return new RelPos(pos().method_10093(direction.method_10153()));
    }

    public static final RelPos ORIGIN = new RelPos(0, 0, 0);
}
